@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20240430';
+our $VERSION = '0.20240531';
 
-# Table last modified: 2024-04-30
+# Table last modified: 2024-05-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,14 +103,14 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6|78)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|0[25]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|3[09]|0[235]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|3(?:8[38]|5[013-589]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|2(?:5[0-2569]|3\d|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:3[03]|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
+    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:[37]2|81|0[23578]|1[14]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
@@ -133,7 +133,7 @@ our %ZIP_TABLE = (
     '135' => '(?:8(?:5(?:48|3[0-358]|7[57-9]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:[46]5|21|50|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|0[236-9]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
+    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|0[23679]|8[0346]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|2[1568]|6[013689]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|(?:45|81)0))',
     '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-3689]|2[0-6])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|22|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
@@ -153,7 +153,7 @@ our %ZIP_TABLE = (
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|[16][25]|0[235]|3[05]|8[57]|5[16-8]|4[034])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
-    '164' => '(?:8(?:6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|5(?:[37]0|55|67|4[015]|2[25]|8[58]|0[1-5])|7(?:25|0[15])))',
+    '164' => '(?:8(?:5(?:[37]0|55|4[015]|2[25]|6[67]|8[58]|0[1-5])|6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
     '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
@@ -169,7 +169,7 @@ our %ZIP_TABLE = (
     '178' => '(?:8(?:5(?:11|67|0[12])|6(?:[68]6|01|24)))',
     '179' => '(?:8(?:9(?:0[134679]|1[14])|501))',
     '180' => '(?:8(?:5(?:66|80|1[79]|2[027]|7[17]|3[138]|0[58])|6(?:29|33|1[018]|0[28])|7(?:50|77)))',
-    '181' => '(?:8(?:5(?:41|67|3[135]|7[17]|8[568]|2[128]|1[178]|0[35]|5[15])|6(?:22|33|48|1[124]|0[18])|001))',
+    '181' => '(?:8(?:5(?:41|67|3[135]|7[17]|8[568]|2[128]|1[178]|0[35]|5[15])|6(?:[04]8|22|33|1[124])|001))',
     '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|0[12])|00[16]))',
     '183' => '(?:8(?:5(?:61|70|85|1[1-469]|2[124-689]|5[013]|3[02469]|4[0189]|0[1256])|70[1-35-7]))',
     '184' => '(?:8(?:5(?:[34]3|22|95|1[015]|5[58]|7[57]|0[1-58]|8[1458])|795))',
@@ -196,9 +196,9 @@ our %ZIP_TABLE = (
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
     '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|8[356]|3[178]|4[013-578]|7[067]|1[12]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
-    '211' => '(?:8(?:5(?:40|66|3[03]|2[02]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
+    '211' => '(?:8(?:5(?:22|66|3[03]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
     '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|8[1-5]|0[2589]|1[01])|60[2-4]))',
-    '213' => '(?:85(?:66|0[2357]|2[0-25]|1[125-7]|3[35]|7[0367]|5[0138]|8[06-9]))',
+    '213' => '(?:85(?:66|0[2357]|8[07-9]|2[0-25]|1[125-7]|3[35]|7[0367]|5[0138]))',
     '214' => '(?:85(?:[26]5|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
@@ -207,7 +207,7 @@ our %ZIP_TABLE = (
     '222' => '(?:8(?:5(?:3[03]|8[056]|6[1-6]|7[57]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:85(?:7[027]|[58][058]|1[0-25]|2[0-35-7]|6[067]|4[0-2]|0[125-8]|3[039]))',
     '224' => '(?:8(?:5(?:39|40|78|0[1-57]|8[058]|1[05]|5[01]|2[024])|6(?:01|8[68])))',
-    '225' => '(?:85(?:[28]5|[56]0|13|0[1-38]|3[059]))',
+    '225' => '(?:85(?:[56]0|13|85|2[25]|0[1-38]|3[059]))',
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
     '230' => '(?:8(?:5(?:11|7[17]|0[14]|5[05])|6(?:[68]6|11|28)|765))',
@@ -470,7 +470,7 @@ our %ZIP_TABLE = (
     '497' => '(?:8(?:5(?:[04][158]|3[138]|2[27]|1[0-2])|60[12]))',
     '498' => '(?:850[1-35])',
     '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|2[1-357-9]|1[015-8]|3[0-479]|5[0-5]|0[1-378])))',
-    '501' => '(?:(?:0(?:49[2-8]|69[2-8]|29[2-6]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|[25]92)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
+    '501' => '(?:(?:0(?:69[2-8]|29[2-6]|49[25-8]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|592)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
     '502' => '(?:8(?:5(?:[12]1|58|67|85|0[13])|792))',
     '503' => '(?:(?:8(?:5(?:5[02-46-9]|2[0-3]|[01][1-9]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[258]|29[25]|[46]95|392)|1(?:39[2-6]|59[235]|696)))',
     '504' => '(?:8(?:5(?:[48]5|11|0[14]|5[15])|7(?:10|0[12])|6(?:01|42)))',
@@ -494,7 +494,7 @@ our %ZIP_TABLE = (
     '522' => '(?:(?:8(?:5(?:11|0[135]|4[03]|3[39]|8[58]|2[023])|6(?:55|66))|029[27]))',
     '523' => '(?:8(?:5(?:[23]3|5[58]|1[05]|0[1-37])|651))',
     '524' => '(?:85(?:01|24|77|85))',
-    '525' => '(?:85(?:77|6[67]|2[0-256]|[58][58]|1[15]|0[125]))',
+    '525' => '(?:85(?:77|1[015]|6[67]|2[0-256]|[58][58]|0[125]))',
     '526' => '(?:(?:8(?:5(?:01|45|58|8[05])|6(?:60|86))|029[23]))',
     '527' => '(?:(?:8(?:5(?:[27]7|42|0[158]|8[058]|6[67]|1[12]|5[0458])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
@@ -528,10 +528,10 @@ our %ZIP_TABLE = (
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[126]|6[01])|6(?:11|58|0[1245])|729))',
-    '560' => '(?:85(?:79|80|4[38]|5[0-25]|6[0157]|3[12]|0[56]))',
+    '560' => '(?:85(?:13|79|80|4[38]|5[0-25]|6[0157]|3[12]|0[56]))',
     '561' => '(?:85(?:[23]0|01|77|5[058]|1[01]))',
     '562' => '(?:8(?:5(?:11|22|43|55|8[0568]|0[58]|6[0278])|6(?:78|86)))',
-    '563' => '(?:(?:85(?:[67]7|10|88)|0[23]92))',
+    '563' => '(?:(?:8(?:5(?:[67]7|10|88)|688)|0[23]92))',
     '564' => '(?:8(?:5(?:23|5[015]|0[13]|6[57]|1[15])|6(?:80|5[01])))',
     '565' => '(?:85(?:11|40|85))',
     '566' => '(?:8(?:5(?:[58]5|01|13|66)|686))',
@@ -548,10 +548,10 @@ our %ZIP_TABLE = (
     '578' => '(?:85(?:22|55|77|3[35]|8[58]|0[12]|1[15]))',
     '579' => '(?:8502)',
     '580' => '(?:8(?:50[1-5]|601))',
-    '581' => '(?:8(?:5(?:11|39|58|85|0[25])|686))',
+    '581' => '(?:8(?:5(?:11|39|85|0[25]|5[58])|686))',
     '582' => '(?:85(?:01|55|8[25]))',
     '583' => '(?:85(?:01|22|63|3[3-5]|8[0358]|5[058]))',
-    '584' => '(?:8(?:5(?:[13]1|22|40|85)|651))',
+    '584' => '(?:8(?:5(?:[013]1|22|40|85)|651))',
     '585' => '(?:85(?:01|85|5[05]))',
     '586' => '(?:85(?:[01]1|[58]5|77|2[18]))',
     '587' => '(?:85(?:55|77|8[56]))',
@@ -575,7 +575,7 @@ our %ZIP_TABLE = (
     '606' => '(?:85(?:11|22|36|40|[58][58]|0[1257]))',
     '607' => '(?:85[017]1)',
     '610' => '(?:(?:0(?:3(?:80|9[3-7])|19[256]|28[179])|119[258]))',
-    '611' => '(?:8(?:5(?:[58]5|01)|660))',
+    '611' => '(?:8(?:5(?:01|55|8[58])|660))',
     '612' => '(?:8(?:5(?:01|22|77|85|3[03]|5[058]|1[15])|6(?:02|60|77|86)))',
     '613' => '(?:8585)',
     '614' => '(?:85(?:[01]1|88))',
@@ -586,30 +586,30 @@ our %ZIP_TABLE = (
     '619' => '(?:(?:02(?:9[245]|8[02-9])|1(?:[12]95|393)))',
     '620' => '(?:(?:850[1-8]|149[23]))',
     '621' => '(?:8(?:5(?:[58]5|01)|686))',
-    '622' => '(?:(?:0292|8651))',
+    '622' => '(?:(?:8(?:50|65)1|0292))',
     '623' => '(?:85(?:01|88))',
     '624' => '(?:8(?:555|686))',
     '625' => '(?:8(?:5(?:[58]5|0[1-3]|1[01])|666))',
     '626' => '(?:(?:85(?:[07]1|10)|0493))',
     '627' => '(?:8(?:5(?:55|67|70)|688))',
     '629' => '(?:(?:0(?:19[26-8]|39[28])|2(?:292|498)|1192))',
-    '630' => '(?:(?:8(?:5(?:3[0356]|2[0289]|1[28]|6[367]|7[0578]|0[1-3568]|8[015-9]|4[038]|5[0258])|6(?:7[07]|[68][68]|5[15]))|0(?:2(?:88|9[23])|192)|2192))',
+    '630' => '(?:(?:8(?:5(?:3[0356]|2[0289]|1[28]|6[367]|7[0578]|0[1-3568]|4[038]|5[0258]|8[0157-9])|6(?:7[07]|[68][68]|5[15]))|0(?:2(?:88|9[23])|192)|2192))',
     '631' => '(?:85(?:[58]5|11|2[2-4]|0[1-35]))',
     '632' => '(?:(?:8(?:5(?:[14]0|[67]7|8[578]|5[258])|6(?:79|88))|0292))',
-    '633' => '(?:(?:8(?:5(?:01|38|85)|686)|0(?:29[28]|39[28])|2[14]92))',
+    '633' => '(?:(?:8(?:5(?:[58]5|01|38)|686)|0(?:29[28]|39[28])|2[14]92))',
     '634' => '(?:85(?:5[015]|2[1-4]|8[056]|0[1-35-7]|1[01]|6[017]))',
-    '635' => '(?:8(?:5(?:30|85|0[12]|2[08]|1[15])|787))',
+    '635' => '(?:8(?:5(?:30|85|0[1-3]|2[08]|1[15])|787))',
     '636' => '(?:(?:0(?:29[2-58]|19[238]|39[238])|8(?:5(?:[358]5|11|0[13])|798)))',
     '637' => '(?:85[01]1)',
     '638' => '(?:(?:85(?:[0256]1|10)|0[23]92))',
-    '639' => '(?:(?:1(?:1(?:9[26-8]|8[3468])|0(?:8[0-259]|9[35]))|2(?:19[578]|29[258])|3(?:192|594)|029[238]))',
+    '639' => '(?:(?:1(?:1(?:9[26-8]|8[3468])|0(?:8[0-259]|9[35]))|2(?:19[578]|29[258])|3(?:19[24]|594)|029[238]))',
     '640' => '(?:(?:8(?:5(?:6[04-7]|7[057]|2[045]|0[1-357-9]|4[014-6]|5[0-25-8]|8[0-25689]|1[0-69]|3[03568])|6(?:8[67]|6[68]|5[1-79])|787)|119[26]|0492))',
     '641' => '(?:8(?:5(?:0[189]|1[01])|770))',
-    '642' => '(?:8501)',
+    '642' => '(?:85(?:01|55))',
     '643' => '(?:8501)',
     '644' => '(?:(?:86(?:55|86)|1292))',
     '645' => '(?:85[01]1)',
-    '646' => '(?:(?:8(?:5(?:[01]1|8[058]|4[45]|5[08])|660)|(?:02|1[14])92))',
+    '646' => '(?:(?:8(?:5(?:01|8[058]|4[45]|5[08]|1[01])|660)|(?:02|1[14])92))',
     '647' => '(?:(?:1(?:294|792)|855[15]))',
     '648' => '(?:(?:0(?:2(?:8\d|9[2-8])|198|392)|85(?:41|85)))',
     '649' => '(?:(?:6(?:49[2-4]|59[235]|[126]92)|(?:[04]1|35)92|219[2358]|719[245]))',
@@ -617,13 +617,13 @@ our %ZIP_TABLE = (
     '651' => '(?:(?:8(?:5(?:[58]5|67|70|1[124]|0[12]|2[56])|798)|2(?:1(?:9[467]|8[0178])|49[24]|295)|01(?:7[0-278]|9[35]|8[578])|1(?:195|596)))',
     '652' => '(?:85(?:[17]0|01|85|5[05]))',
     '653' => '(?:8(?:5(?:70|85)|76[267]))',
-    '654' => '(?:(?:85(?:70|85)|019[2358]))',
+    '654' => '(?:(?:85(?:11|70|85)|019[2358]))',
     '655' => '(?:8570)',
     '656' => '(?:(?:1(?:59[28]|395|792)|2(?:[2-4]92|193)|8(?:6[568]6|555)|0(?:492|595)))',
     '657' => '(?:85(?:01|70))',
     '658' => '(?:85(?:01|70|5[58]))',
     '659' => '(?:85(?:11|0[1-3]))',
-    '660' => '(?:85(?:[01]1|33|67|4[04]|5[058]|8[0258]))',
+    '660' => '(?:8(?:5(?:[01]1|33|67|4[04]|5[058]|8[0258])|001))',
     '661' => '(?:8(?:5(?:[23]0|01|77|6[47]|5[058]|8[58]|1[01])|661))',
     '662' => '(?:85(?:[34]3|10|21|67|8[056]|5[258]|0[1-35]))',
     '663' => '(?:8(?:5(?:[13]0|[67]7|01|45|58|8[568])|601))',
@@ -631,14 +631,14 @@ our %ZIP_TABLE = (
     '665' => '(?:8(?:5(?:01|43|67|5[058]|8[58])|665))',
     '666' => '(?:(?:0292|8501))',
     '667' => '(?:(?:8(?:555|651)|0198))',
-    '668' => '(?:(?:8(?:6(?:66|5[05])|501)|0(?:29[238]|393)))',
+    '668' => '(?:(?:8(?:6(?:66|5[05])|5(?:01|62))|0(?:29[238]|393)))',
     '669' => '(?:(?:3(?:39[24-6]|19[28]|69[23]|495|892)|5(?:19[2378]|39[258]|292)|6(?:[2578]92|19[25])|2(?:[12]92|397)|159[25]|4[13]92))',
     '670' => '(?:8(?:5(?:3[03]|2[04]|4[34]|7[057]|8[058]|0[1-356]|6[067]|5[0458]|1[017])|6(?:5[25]|6[068]|7[57]|8[029])))',
     '671' => '(?:(?:1(?:2(?:9[235]|8[0-35689])|6(?:92|8[0-248])|1(?:92|8[018])|59[235]|39[23])|2(?:19[238]|59[358]|28[08])|419[23]|0295))',
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
-    '673' => '(?:(?:8(?:5(?:[01]1|22|85)|6(?:66|8[68]))|1(?:49[3-5]|192|395)|0[45]92))',
+    '673' => '(?:(?:8(?:5(?:[01]1|[58]5|22)|6(?:66|8[68]))|1(?:49[2-5]|192|395)|0[45]92))',
     '674' => '(?:8(?:5(?:01|85)|686))',
-    '675' => '(?:(?:8(?:5(?:22|33|66|77|88|1[019]|5[58]|0[15])|6(?:11|8[68]))|01(?:8[0-68]|9[2-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
+    '675' => '(?:(?:8(?:5(?:22|33|77|88|1[019]|6[67]|5[58]|0[15])|6(?:11|8[68]))|01(?:8[0-68]|9[2-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
     '676' => '(?:8(?:5(?:01|33|40|58|66|85|1[03])|6(?:55|7[07]|8[68])))',
     '677' => '(?:851[01])',
     '678' => '(?:(?:1(?:29[257]|19[58])|0(?:19[235]|292)|85(?:43|85)))',
@@ -718,7 +718,7 @@ our %ZIP_TABLE = (
     '757' => '(?:(?:8(?:5(?:11|85)|6(?:34|86))|029[28]))',
     '758' => '(?:8(?:6(?:15|86|4[58])|5(?:[58]5|70)))',
     '759' => '(?:(?:(?:22|55)92|029[2357]|419[2468]|659[25]))',
-    '760' => '(?:8(?:5(?:90|4[5-7]|5[0-2457-9]|3[0346-9]|2[0-57]|6[0-246-9]|8[0235689]|1[0-8]|7[0-69]|0[2-578])|6(?:71|8[6-8]|6[0178]|3[04689]|5[05]|1[0458]|4[48]|2[013-6]|0[13478])))',
+    '760' => '(?:8(?:5(?:90|4[5-7]|5[0-2457-9]|3[0346-9]|1[1-8]|2[0-57]|6[0-246-9]|8[0235689]|7[0-69]|0[2-578])|6(?:71|8[6-8]|6[0178]|3[04689]|5[05]|1[0458]|4[48]|2[013-6]|0[13478])))',
     '761' => '(?:(?:8(?:5(?:[014]1|20|8[124-689]|7[78]|6[5-7]|3[38]|5[0158])|601|777)|0(?:1(?:8[5-9]|9[2-8])|39[3-7]|49[23]|79[35]|692)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-4])|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
     '762' => '(?:8(?:5(?:50|1[015]|0[23578])|60[12]))',
     '763' => '(?:8(?:5(?:0[1-478]|1[0-368])|60[358]))',
@@ -818,7 +818,7 @@ our %ZIP_TABLE = (
     '857' => '(?:(?:8(?:5(?:33|58|66|0[1-38]|8[58]|7[57]|1[01])|6(?:[68]6|11))|2(?:49[24]|392)|4(?:495|592)|119[2-578]|0[134]92))',
     '858' => '(?:85(?:01|55|8[0589]))',
     '859' => '(?:(?:3(?:79[2378]|29[238]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
-    '860' => '(?:8(?:5(?:3[013469]|1\d|8[014-8]|7[057]|0[1-9]|6[5-8]|5[0-24-8]|4[01357]|2[0-8])|6(?:2[245]|1[1589]|8[168]|5[05]|0[1-68]|6[08])|7(?:39|9[25-7])))',
+    '860' => '(?:8(?:5(?:3[013469]|8[014-8]|7[057]|[01][1-9]|6[5-8]|5[0-24-8]|4[01357]|2[0-8])|6(?:2[245]|1[1589]|8[168]|5[05]|0[1-68]|6[08])|7(?:39|9[25-7])))',
     '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|4(?:1(?:89|9[23568])|[34]92|696)|1(?:19[23578]|39[24]|295)|3(?:19[2-6]|29[56]|592)|5(?:49[2-5]|59[28]|292)|85(?:01|14|38|2[089])|2(?:29[35-7]|[14]92)|6[13]95|7292))',
     '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[359]|0[139]|1[0-2]|8[08]|5[125])|7(?:44|1[06]|9[34]|0[12]|2[01])|5(?:[58]5|10|0[2458]|7[01])))',
     '863' => '(?:(?:8(?:6(?:31|86)|5[58]5)|2(?:292|895)|1992))',
@@ -853,7 +853,7 @@ our %ZIP_TABLE = (
     '892' => '(?:8(?:5(?:20|4[03]|1[25]|8[568]|5[058]|6[367]|3[01359]|0[125])|6(?:11|26|33|50|77|88|0[13])))',
     '893' => '(?:(?:1(?:19[28]|69[23]|298)|8(?:5(?:10|0[12])|611)|(?:02|2[34])92))',
     '894' => '(?:(?:8(?:5(?:11|55|67|0[17]|8[58])|6(?:01|55|77|88))|(?:3[13]|1[25])92|0(?:192|595)))',
-    '895' => '(?:(?:8(?:5(?:40|55|88|0[1-6]|1[59])|6(?:01|50|86))|1(?:29[2356]|49[23]|595)|229[28]|0292))',
+    '895' => '(?:(?:8(?:5(?:40|55|88|0[1-6]|1[59])|6(?:01|50|86))|1(?:29[2356]|492|595)|229[28]|0292))',
     '896' => '(?:(?:1(?:[13]92|696)|86(?:01|86)))',
     '897' => '(?:(?:039[23]|8501))',
     '898' => '(?:8501)',
@@ -934,7 +934,7 @@ our %ZIP_TABLE = (
     '975' => '(?:8(?:585|686))',
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:0(?:19[25-8]|69[56])|2(?:39[2-4]|195|792)|1(?:[135]92|495)))',
-    '980' => '(?:(?:8(?:4(?:7[78]|4[1-35-8]|8[014-8]|0[1-36-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|7\d|4[346]|2[01569]|0[158]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|7[17]|3[1-36-9]|2[12])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
+    '980' => '(?:(?:8(?:4(?:7[78]|4[1-35-8]|8[014-8]|0[1-36-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|7\d|4[346]|0[158]|2[1569]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|7[17]|3[1-36-9]|2[12])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
     '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|2[23]|6[03]|5[0-26-8]|0[25]|7[07]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
     '982' => '(?:8(?:5(?:31|44|66|77|2[13]|8[58]|5[15]|1[01]|0[125])|601|798))',
     '983' => '(?:8(?:5(?:43|70|85|6[0257]|0[1247]|3[367]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)|477))',
